@@ -5,5 +5,5 @@ class news_feed:
 
     @staticmethod
     def get(client):
-        response = http.get(f'https://openvk.su/method/Newsfeed.get?access_token={client}')
+        response = http.get(f'https://{client["domen"]}/method/Newsfeed.get?access_token={client["token"]}')
         return json.loads(response.text)['response']
\ No newline at end of file
